@@ -31,9 +31,6 @@
 
 	var ChatView = Marionette.View.extend({
 
-		temporaryNearMessages: 0,
-		sameAuthorMessages: 0,
-
 		className: 'chat',
 
 		lastComments: [],
@@ -97,10 +94,17 @@
 						// highlighting loads the avatars.
 						var $li = $(li);
 						var $avatar = $li.find('.avatar');
-						if ($avatar.data('user-id') === 'all') {
+						var avatarSize = 32;
+						var userId = '' + $avatar.data('user-id');
+						if (userId === 'all') {
 							$avatar.addClass('avatar icon icon-contacts');
+						} else if (userId && userId.indexOf('guest/') !== 0) {
+							$avatar.avatar(userId, avatarSize);
 						} else {
-							$avatar.avatar($avatar.data('user-id'), 32);
+							var displayName = $avatar.data('user-display-name');
+							var customName = displayName !== t('spreed', 'Guest') ? displayName : '';
+							$avatar.imageplaceholder(customName ? customName.substr(0, 1) : '?', customName, avatarSize);
+							$avatar.css('background-color', '#b9b9b9');
 						}
 						return $li;
 					},
@@ -202,13 +206,14 @@
 			}
 
 			return this._addCommentTemplate(_.extend({
-				actorId: OC.getCurrentUser().uid,
-				actorDisplayName: OC.getCurrentUser().displayName,
+				isGuest: !OCA.Talk.getCurrentUser().uid,
+				actorId: OCA.Talk.getCurrentUser().uid || 'guest/' + this.model.get('hashedSessionId'),
+				actorDisplayName: OCA.Talk.getCurrentUser().displayName || '',
 				newMessagePlaceholder: newMessagePlaceholder,
 				submitText: submitText,
 				shareText: t('spreed', 'Share'),
 				isReadOnly: isReadOnly,
-				canShare: !isReadOnly && OC.getCurrentUser().uid,
+				canShare: !isReadOnly && OCA.Talk.getCurrentUser().uid,
 			}, params));
 		},
 
@@ -219,7 +224,7 @@
 
 			params = _.extend({
 				// TODO isUserAuthor is not properly set for guests
-				isUserAuthor: OC.getCurrentUser().uid === params.actorId,
+				isUserAuthor: OCA.Talk.getCurrentUser().uid === params.actorId,
 				isGuest: params.actorType === 'guests',
 			}, params);
 
@@ -231,19 +236,32 @@
 		},
 
 		onRender: function() {
-			delete this._lastAddedMessageModel;
+			delete this._lastAppendedMessageModel;
+			delete this._lastPrependedMessageModel;
+
+			delete this._$lastPrependedMessage;
+
+			this._newestTemporaryNearMessages = 0;
+			this._newestSameAuthorMessages = 0;
+			this._oldestTemporaryNearMessages = 0;
+			this._oldestSameAuthorMessages = 0;
 
 			this.$el.find('.emptycontent').after(this.addCommentTemplate({}));
 
 			this.$el.find('.has-tooltip').tooltip({container: this._tooltipContainer});
 			this.$container = this.$el.find('ul.comments');
 
+			this.$container.scroll(this._loadOlderMessagesOnScrollToTop.bind(this));
+
 			this._virtualList = new OCA.SpreedMe.Views.VirtualList(this.$container);
 
-			if (OC.getCurrentUser().uid) {
-				this.$el.find('.avatar').avatar(OC.getCurrentUser().uid, 32, undefined, false, undefined, OC.getCurrentUser().displayName);
+			var avatarSize = 32;
+			if (OCA.Talk.getCurrentUser().uid) {
+				this.$el.find('.avatar').avatar(OCA.Talk.getCurrentUser().uid, avatarSize, undefined, false, undefined, OCA.Talk.getCurrentUser().displayName);
 			} else {
-				this.$el.find('.avatar').imageplaceholder('?', this.getOption('guestNameModel').get('nick'), 128);
+				var displayName = this.getOption('guestNameModel').get('nick');
+				var customName = displayName !== t('spreed', 'Guest') ? displayName : '';
+				this.$el.find('.avatar').imageplaceholder(customName ? customName.substr(0, 1) : '?', customName, avatarSize);
 				this.$el.find('.avatar').css('background-color', '#b9b9b9');
 				this.showChildView('guestName', this._guestNameEditableTextLabel, { replaceElement: true, allowMissingEl: true } );
 			}
@@ -302,7 +320,7 @@
 			this._tooltipContainer = tooltipContainer;
 
 			// Update tooltips
-			this.$el.find('.has-tooltip').tooltip('destroy');
+			this.$el.find('.has-tooltip').tooltip('dispose');
 			this.$el.find('.has-tooltip').tooltip({container: this._tooltipContainer});
 		},
 
@@ -373,10 +391,25 @@
 		},
 
 		/**
-		 * Reloads the message list.
+		 * Reloads the message list and updates internal values based on the
+		 * size of the chat view.
 		 *
 		 * This needs to be called whenever the size of the chat view has
 		 * changed.
+		 */
+		handleSizeChanged: function() {
+			this.reloadMessageList();
+
+			if (this.$el && this.$el.find('.newCommentRow .message').length > 0) {
+				// Before the 3.0.0 release jQuery rounded the height to the nearest
+				// integer, but Firefox has subpixel accuracy, so the height
+				// returned by jQuery can not be used in the calculations.
+				this._newMessageFieldHeight = this.$el.find('.newCommentRow .message').get(0).getBoundingClientRect().height;
+			}
+		},
+
+		/**
+		 * Reloads the message list.
 		 *
 		 * When the message list is reloaded its size may have changed (for
 		 * example, if the chat view was detached from the main view and
@@ -420,6 +453,34 @@
 			this.reloadMessageList();
 		},
 
+		_loadOlderMessagesOnScrollToTop: function() {
+			if (!this.collection.canLoadOlderMessages()) {
+				return;
+			}
+
+			if (this.$container.scrollTop() > this.$container.outerHeight()) {
+				return;
+			}
+
+			this._loadOlderMessages();
+		},
+
+		_loadOlderMessages: function() {
+			if (this._loadOlderMessagesPromise === this.collection.loadOlderMessages()) {
+				return;
+			}
+
+			this._loadOlderMessagesPromise = this.collection.loadOlderMessages();
+			this._loadOlderMessagesPromise.then(function() {
+				delete this._loadOlderMessagesPromise;
+			}.bind(this)).fail(function() {
+				delete this._loadOlderMessagesPromise;
+
+				// Retry on failure.
+				this._loadOlderMessages();
+			}.bind(this));
+		},
+
 		_formatItem: function(commentModel) {
 			// PHP timestamp is second-based; JavaScript timestamp is
 			// millisecond based.
@@ -438,7 +499,10 @@
 			formattedMessage = this._plainToRich(formattedMessage);
 			formattedMessage = formattedMessage.replace(/\n/g, '<br/>');
 			formattedMessage = OCA.SpreedMe.Views.RichObjectStringParser.parseMessage(
-				formattedMessage, commentModel.get('messageParameters'));
+				formattedMessage, commentModel.get('messageParameters'), {
+					userId: OCA.Talk.getCurrentUser().uid,
+					sessionHash: this.model.get('hashedSessionId'),
+				});
 
 			var data = _.extend({}, commentModel.attributes, {
 				actorDisplayName: actorDisplayName,
@@ -477,62 +541,166 @@
 			});
 		},
 
-		_onAddModelStart: function() {
-			this._virtualList.appendElementStart();
+		_onAddModelStart: function(options) {
+			var append = true;
+			if (options && options.at === 0) {
+				append = false;
+			}
 
-			this._scrollToNew = this._virtualList.getLastElement() === this._virtualList.getLastVisibleElement();
+			if (append) {
+				this._virtualList.appendElementStart();
+			} else {
+				this._virtualList.prependElementStart();
+			}
+
+			// If there are no elements the virtual list will automatically
+			// scroll to the bottom when a new batch of elements is prepended;
+			// otherwise it will keep the current scroll position.
+			this._scrollToNew = false;
+
+			if (append) {
+				this._scrollToNew = this._virtualList.getLastElement() === this._virtualList.getLastVisibleElement();
+			}
 		},
 
-		_onAddModel: function(model) {
+		/**
+		 * Renders and adds a new chat message view for the model added to the
+		 * collection.
+		 *
+		 * This is expected to be called as a handler for "add" events in a
+		 * Backbone collection; models must be either appended or prepended to
+		 * the collection; there is no support for models inserted at an
+		 * arbitrary position. Moreover, when models are prepended to the
+		 * collection they must be prepended one by one; prepending a group of
+		 * several messages, even if they are properly sorted from oldest to
+		 * newest, is not supported. On the other hand, appending several models
+		 * at once is supported (but note that in this case this method will be
+		 * called once for each model anyway).
+		 *
+		 * @param {Backbone.Model} model the added model.
+		 * @param {Backbone.Collection} collection unused.
+		 * @param Array options "at === 0" to prepend, otherwise appends.
+		 */
+		_onAddModel: function(model, collection, options) {
+			var append = true;
+			if (options && options.at === 0) {
+				append = false;
+			}
+
 			var $el = $(this.commentTemplate(this._formatItem(model)));
-			this._virtualList.appendElement($el);
 
-			if (this._modelsHaveSameActor(this._lastAddedMessageModel, model) &&
-				this._modelsAreTemporaryNear(this._lastAddedMessageModel, model, 3600) &&
-				this.sameAuthorMessages < 20
+			if (append) {
+				this._virtualList.appendElement($el);
+			} else {
+				this._virtualList.prependElement($el);
+			}
 
-			) {
-				this.sameAuthorMessages++;
-				if (this._modelsAreTemporaryNear(this._lastAddedMessageModel, model) &&
-					this.temporaryNearMessages < 5) {
-					$el.addClass('grouped');
+			if (append) {
+				if (this._modelsHaveSameActor(this._lastAppendedMessageModel, model) &&
+					this._modelsAreTemporaryNear(this._lastAppendedMessageModel, model, 3600) &&
+					this._newestSameAuthorMessages < 20
+				) {
+					this._newestSameAuthorMessages++;
 
-					this.temporaryNearMessages++;
+					if (this._modelsAreTemporaryNear(this._lastAppendedMessageModel, model) &&
+						this._newestTemporaryNearMessages < 5) {
+						$el.addClass('grouped');
+
+						this._newestTemporaryNearMessages++;
+					} else {
+						$el.addClass('same-author');
+						this._newestTemporaryNearMessages = 0;
+					}
 				} else {
-					$el.addClass('same-author');
-					this.temporaryNearMessages = 0;
+					this._newestSameAuthorMessages = 0;
+					this._newestTemporaryNearMessages = 0;
 				}
 			} else {
-				this.sameAuthorMessages = 0;
-				this.temporaryNearMessages = 0;
+				if (this._modelsHaveSameActor(this._lastPrependedMessageModel, model) &&
+					this._modelsAreTemporaryNear(this._lastPrependedMessageModel, model, 3600) &&
+					this._oldestSameAuthorMessages < 20
+				) {
+					this._oldestSameAuthorMessages++;
+
+					if (this._modelsAreTemporaryNear(this._lastPrependedMessageModel, model) &&
+						this._oldestTemporaryNearMessages < 5) {
+						this._$lastPrependedMessage.addClass('grouped');
+
+						this._oldestTemporaryNearMessages++;
+					} else {
+						this._$lastPrependedMessage.addClass('same-author');
+						this._oldestTemporaryNearMessages = 0;
+					}
+
+					// This is needed for the first existing comment, and it
+					// will be simply ignored for the comments being prepended.
+					this._virtualList.updateElement(this._$lastPrependedMessage);
+				} else {
+					this._oldestSameAuthorMessages = 0;
+					this._oldestTemporaryNearMessages = 0;
+				}
 			}
 
 			// PHP timestamp is second-based; JavaScript timestamp is
 			// millisecond based.
 			model.set('date', new Date(model.get('timestamp') * 1000));
 
-			if (!this._lastAddedMessageModel || !this._modelsHaveSameDate(this._lastAddedMessageModel, model)) {
+			if (!append || (!this._lastAppendedMessageModel || !this._modelsHaveSameDate(this._lastAppendedMessageModel, model))) {
 				$el.attr('data-date', this._getDateSeparator(model.get('date')));
 				$el.addClass('showDate');
 			}
 
-			// Keeping the model for the last added message is not only
-			// practical, but needed, as the models for previous messages are
-			// removed from the collection each time a new set of messages is
-			// received.
-			this._lastAddedMessageModel = model;
+			if (!append && this._modelsHaveSameDate(this._lastPrependedMessageModel, model)) {
+				this._$lastPrependedMessage.removeClass('showDate');
+				// This is needed for the first existing comment, and it will be
+				// simply ignored for the comments being prepended.
+				this._virtualList.updateElement(this._$lastPrependedMessage);
+			}
+
+			// Keeping the models for the last appended and prepended messages
+			// is not only practical, but needed, as the models for previous
+			// messages are removed from the collection each time a new set of
+			// messages is received.
+			if (append || !this._lastAppendedMessageModel) {
+				this._lastAppendedMessageModel = model;
+			}
+			if (!append || !this._lastPrependedMessageModel) {
+				this._lastPrependedMessageModel = model;
+			}
+
+			// The element for the last prepended message is kept to update it
+			// as needed when new messages are prepended.
+			if (!append|| !this._$lastPrependedMessage) {
+				this._$lastPrependedMessage = $el;
+			}
 
 			this._postRenderItem(model, $el);
 		},
 
-		_onAddModelEnd: function() {
+		_onAddModelEnd: function(options) {
+			var append = true;
+			if (options && options.at === 0) {
+				append = false;
+			}
+
 			this.$el.find('.emptycontent').toggleClass('hidden', true);
 
-			this._virtualList.appendElementEnd();
+			if (append) {
+				this._virtualList.appendElementEnd();
+			} else {
+				this._virtualList.prependElementEnd();
+			}
 
 			if (this._scrollToNew) {
 				this._virtualList.scrollTo(this._virtualList.getLastElement());
 			}
+
+			// Keep loading older messages until there is a scroll bar;
+			// otherwise the user would not be able to scroll to load further
+			// messages.
+			if (!this._virtualList.isScrollable() && this.collection.canLoadOlderMessages()) {
+				this._loadOlderMessages();
+			}
 		},
 
 		_getDateSeparator: function(timestamp) {
@@ -603,41 +771,46 @@
 			$el.find('.has-tooltip').tooltip({container: this._tooltipContainer});
 
 			var setAvatar = function($element, size) {
-				if ($element.data('user-id')) {
-					if ($element.data('user-id') === 'all') {
+				var userId = '' + $element.data('user-id');
+				if (userId && userId.indexOf('guest/') !== 0) {
+					if (userId === 'all') {
 						$element.addClass('avatar icon icon-contacts');
 					} else {
-						$element.avatar($element.data('user-id'), size, undefined, false, undefined, $element.data('user-display-name'));
+						$element.avatar(userId, size, undefined, false, undefined, $element.data('user-display-name'));
 					}
 				} else {
-					$element.imageplaceholder('?', $element.data('displayname'), size);
+					var displayName = $element.data('user-display-name');
+					var customName = displayName !== t('spreed', 'Guest') ? displayName : '';
+					$element.imageplaceholder(customName ? customName.substr(0, 1) : '?', customName, size);
 					$element.css('background-color', '#b9b9b9');
 				}
 			};
 			$el.find('.authorRow .avatar').each(function() {
+				var avatarSize = 32;
 				if (model && model.get('actorType') === 'bots') {
 					if (model.get('actorId') === 'changelog') {
 						$(this).addClass('icon icon-changelog');
 					} else {
-						$(this).imageplaceholder('>_', $(this).data('displayname'), 32);
+						$(this).imageplaceholder('>_', $(this).data('displayname'), avatarSize);
 						$(this).css('background-color', '#363636');
 					}
 				} else {
-					setAvatar($(this), 32);
+					setAvatar($(this), avatarSize);
 				}
 			});
 			var inlineAvatars = $el.find('.message .avatar');
 			if ($($el.context).hasClass('message')) {
 				inlineAvatars = $el.find('.avatar');
 			}
+			var inlineAvatarSize = 16;
 			inlineAvatars.each(function () {
-				setAvatar($(this), 16);
+				setAvatar($(this), inlineAvatarSize);
 			});
 
-			if (OC.getCurrentUser().uid &&
+			if (OCA.Talk.getCurrentUser().uid &&
 				model &&
 				model.get('actorType') === 'users' &&
-				model.get('actorId') !== OC.getCurrentUser().uid) {
+				model.get('actorId') !== OCA.Talk.getCurrentUser().uid) {
 				$el.find('.authorRow .avatar, .authorRow .author').contactsMenu(
 					model.get('actorId'), 0, $el.find('.authorRow'));
 			}
@@ -654,7 +827,7 @@
 			});
 
 			// Contacts menu is not shown in public view.
-			if (!OC.getCurrentUser().uid) {
+			if (!OCA.Talk.getCurrentUser().uid) {
 				return;
 			}
 
@@ -663,7 +836,7 @@
 				var $avatar = $this.find('.avatar');
 
 				var user = $avatar.data('user-id');
-				if (user !== OC.getCurrentUser().uid) {
+				if (user !== OCA.Talk.getCurrentUser().uid) {
 					$this.contactsMenu(user, 0, $this);
 				}
 			});
@@ -711,7 +884,7 @@
 			img.width = previewSize;
 			img.height = previewSize;
 
-			if (OC.getCurrentUser().uid) {
+			if (OCA.Talk.getCurrentUser().uid) {
 				img.onerror = handlePreviewLoadError;
 				img.src = previewUrl;
 			} else {
@@ -730,6 +903,15 @@
 				$field.data('submitButtonEl', $submitButton);
 			}
 
+			// Pressing Arrow-up/down in an empty/unchanged input brings back the last sent messages
+			if (this.lastComments.length !== 0 && !$field.atwho('isSelecting')) {
+				if (ev.keyCode === 38 || ev.keyCode === 40) {
+					this._loopThroughLastComments(ev, $field);
+				} else {
+					this.currentLastComment = -1;
+				}
+			}
+
 			var newMessageFieldOldHeight = this._newMessageFieldHeight;
 			// Before the 3.0.0 release jQuery rounded the height to the nearest
 			// integer, but Firefox has subpixel accuracy, so the height
@@ -747,16 +929,6 @@
 				$submitButton.click();
 				ev.preventDefault();
 			}
-
-			// Pressing Arrow-up/down in an empty/unchanged input brings back the last sent messages
-			if (this.lastComments.length !== 0 && !$field.atwho('isSelecting')) {
-
-				if (ev.keyCode === 38 || ev.keyCode === 40) {
-					this._loopThroughLastComments(ev, $field);
-				} else {
-					this.currentLastComment = -1;
-				}
-			}
 		},
 
 		_loopThroughLastComments: function(ev, $field) {
@@ -802,8 +974,8 @@
 			$comment.find('.mention-user').each(function () {
 				var $this = $(this),
 					$inserted = $this.parent(),
-					userId = $this.find('.avatar').data('user-id');
-				if (userId.indexOf(' ') !== -1) {
+					userId = '' + $this.find('.avatar').data('user-id');
+				if (userId.indexOf(' ') !== -1 || userId.indexOf('guest/') === 0) {
 					$inserted.html('@"' + userId + '"');
 				} else {
 					$inserted.html('@' + userId);
@@ -846,7 +1018,7 @@
 				message: message
 			};
 
-			if (!OC.getCurrentUser().uid) {
+			if (!OCA.Talk.getCurrentUser().uid) {
 				var guestNick = OCA.SpreedMe.app._localStorageModel.get('nick');
 				if (guestNick) {
 					data.actorDisplayName = guestNick;
@@ -875,6 +1047,14 @@
 			$form.find('.submitLoading').addClass('hidden');
 			$form.find('.message').text('').prop('contenteditable', true);
 
+			// Update the stored height of the new message field after cleaning
+			// it.
+			//
+			// Before the 3.0.0 release jQuery rounded the height to the nearest
+			// integer, but Firefox has subpixel accuracy, so the height
+			// returned by jQuery can not be used in the calculations.
+			this._newMessageFieldHeight = $form.find('.message').get(0).getBoundingClientRect().height;
+
 			$form.find('.message').focus();
 
 			// The new message does not need to be explicitly added to the list
