@@ -1,103 +1,6 @@
 OC.L10N.register(
     "spreed",
     {
-    "{name} (public)" : "{name} (public)",
-    "New conversation …" : "Đàm thoại mới...",
-    "Participants" : "Người tham gia",
-    "Chat" : "Trò chuyện",
-    "Talk" : "Trò chuyện",
-    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
-    "Fullscreen (f)" : "Toàn màn hình (f)",
-    "Copy" : "Sao chép",
-    "Copied!" : "Đã sao chép!",
-    "Not supported!" : "Không hỗ trợ!",
-    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
-    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
-    "Request password" : "Yêu cầu mật khẩu",
-    "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
-    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
-    "Password required" : "Mật khẩu đã được yêu cầu",
-    "Password" : "Mật khẩu",
-    "Cancel" : "Hủy bỏ",
-    "Submit" : "Gửi đi",
-    "Leave call" : "Rời khỏi cuộc gọi",
-    "Join call" : "Tham gia cuộc gọi",
-    "Start call" : "Bắt đầu cuộc gọi",
-    "Share link" : "Chia sẽ liên kết",
-    "Change password" : "Đổi mật khẩu",
-    "Set password" : "Đặt mật khẩu",
-    "Name" : "Tên",
-    "Conversation name" : "Tên đàm thoại",
-    "Rename" : "Đổi tên",
-    "Copy link" : "Sao chép liên kết",
-    "Conversation with {name}" : "Đàm thoại với {name}",
-    "Error occurred while setting password" : "Đã xảy ra lỗi khi đặt mật khẩu",
-    "Link copied!" : "Liên kết đã được sao chép!",
-    "You" : "Bạn",
-    "No messages yet, start the conversation!" : "Chưa có tin nhắn, bắt đầu cuộc trò chuyện!",
-    "New message …" : "Thông điệp mới...",
-    "Send" : "Gửi",
-    "Guest" : "Khách",
-    "[Unknown user name]" : "[Tên người dùng chưa biết]",
-    "Today" : "Hôm nay",
-    "Yesterday" : "Hôm qua",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Error occurred while sending message" : "Đã xảy ra lỗi khi gửi tin nhắn",
-    "File to share" : "Tệp để chia sẻ",
-    "Error while sharing" : "Lỗi khi chia sẻ",
-    "Edit" : "Chỉnh sửa",
-    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
-    "No other people in this call" : "Không có người nào trong cuộc gọi này",
-    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
-    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
-    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
-    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
-    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
-    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
-    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
-    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
-    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
-    "Disable video" : "Tắt Video",
-    "Share screen" : "Chia sẽ màn hình",
-    "Show your screen" : "Hiện màn hình của bạn",
-    "Stop screensharing" : "Ngừng chia sẽ màn hình",
-    "Mute audio (m)" : "Tắt âm thành (m)",
-    "Unmute audio (m)" : "Mở âm thanh (m)",
-    "No audio" : "Không có âm thanh",
-    "Disable video (v)" : "Tắt Video (v)",
-    "Enable video (v)" : "Bật Video (v)",
-    "No Camera" : "Không có Camera",
-    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
-    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
-    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
-    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
-    "Enable screensharing" : "Bật chia sẽ màn hình",
-    "moderator" : "Người kiểm duyệt",
-    "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
-    "Promote to moderator" : "Giới thiệu người kiểm duyệt",
-    "Remove participant" : "Xóa người tham gia",
-    "Add participant …" : "Thêm người tham gia …",
-    "Favorited" : "Được ưa thích",
-    "Remove from favorites" : "Xóa khỏi ưa thích",
-    "Add to favorites" : "Thêm vào ưa thích",
-    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
-    "Delete conversation" : "Xóa đàm thoại",
-    "Your screen" : "Màn hình của bạn",
-    "{participantName}'s screen" : "Màn hình của {participantName}",
-    "Guest's screen" : "Màn hình Khách",
-    "Close" : "Đóng",
-    "Show screen" : "Hiện màn hình",
-    "Enable video" : "Bật Video",
-    "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
-    "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
-    "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
-    "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
-    "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
     "a conversation" : "Một đàm thoại",
     "(Duration %s)" : "(Thời lượng %s)",
     "You attended a call with {user1}" : "Bạn đã tham dự một cuộc gọi với {user1}",
@@ -108,7 +11,8 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3}, {user4} và {user5}",
     "_%n other_::_%n others_" : ["%n khác"],
     "{actor} invited you to {call}" : "{actor} mời bạn tham dự {call}",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Bạn đã được mời đến một <strong>phòng trò chuyện</strong> hoặc có một <strong>cuộc gọi</strong>",
+    "Talk" : "Trò chuyện",
+    "Guest" : "Khách",
     "{actor} created the conversation" : "{actor} đã tạo đàm thoại",
     "You created the conversation" : "Bạn đã tạo đàm thoại",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
@@ -151,6 +55,7 @@ OC.L10N.register(
     "{user} sent you a private message" : "{user} đã gửi cho bạn một tin nhắn riêng",
     "{user} mentioned you in a private conversation" : "{user} đã đề cập đến bạn trong cuộc trò chuyện riêng",
     "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
+    "Join call" : "Tham gia cuộc gọi",
     "{user} invited you to a group conversation: {call}" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm: {call}",
     "{user} wants to talk with you" : "{user} muốn nói chuyện với bạn",
     "A group call has started in {call}" : "Một cuộc gọi nhóm đã được thực hiện trong {call}",
@@ -164,11 +69,27 @@ OC.L10N.register(
     "UDP and TCP" : "UDP và TCP",
     "UDP only" : "Chỉ UDP",
     "TCP only" : "Chỉ TCP",
+    "[Unknown user name]" : "[Tên người dùng chưa biết]",
+    "Copy link" : "Sao chép liên kết",
+    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
+    "Delete conversation" : "Xóa đàm thoại",
+    "Remove from favorites" : "Xóa khỏi ưa thích",
+    "Add to favorites" : "Thêm vào ưa thích",
+    "moderator" : "Người kiểm duyệt",
+    "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
+    "Promote to moderator" : "Giới thiệu người kiểm duyệt",
+    "Remove participant" : "Xóa người tham gia",
+    "Share link" : "Chia sẽ liên kết",
+    "Participants" : "Người tham gia",
+    "Name" : "Tên",
     "Saved" : "Đã lưu",
     "Shared secret" : "Chia sẽ mật khẩu",
     "STUN servers" : "Máy chủ STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
+    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
     "The password is wrong. Try again." : "Sai mật khẩu. Thử lại.",
+    "Password" : "Mật khẩu",
+    "Fullscreen (f)" : "Toàn màn hình (f)",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
     "TURN server" : "Máy chủ TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Máy chủ TURN được sử dụng để ủy quyền lưu lượng truy cập từ những người tham gia đằng sau tường lửa.",
@@ -183,26 +104,92 @@ OC.L10N.register(
     "TURN server shared secret" : "Khóa đã được chia sẽ máy chủ TURN",
     "New public conversation" : "Tạo đàm thoại công khai mới",
     "New group conversation" : "Tạo nhóm đàm thoại mới",
-    "Password request by %s" : "Mật khẩu được yêu cầu bởi %s",
+    "{name} (public)" : "{name} (public)",
+    "New conversation …" : "Đàm thoại mới...",
+    "Chat" : "Trò chuyện",
+    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
+    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
+    "Copy" : "Sao chép",
+    "Copied!" : "Đã sao chép!",
+    "Not supported!" : "Không hỗ trợ!",
+    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
+    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
+    "Request password" : "Yêu cầu mật khẩu",
+    "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
+    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
+    "Password required" : "Mật khẩu đã được yêu cầu",
+    "Cancel" : "Hủy bỏ",
+    "Submit" : "Gửi đi",
+    "Leave call" : "Rời khỏi cuộc gọi",
+    "Start call" : "Bắt đầu cuộc gọi",
+    "Change password" : "Đổi mật khẩu",
+    "Set password" : "Đặt mật khẩu",
+    "Conversation name" : "Tên đàm thoại",
+    "Rename" : "Đổi tên",
+    "Conversation with {name}" : "Đàm thoại với {name}",
+    "Error occurred while setting password" : "Đã xảy ra lỗi khi đặt mật khẩu",
+    "Link copied!" : "Liên kết đã được sao chép!",
+    "You" : "Bạn",
+    "No messages yet, start the conversation!" : "Chưa có tin nhắn, bắt đầu cuộc trò chuyện!",
+    "New message …" : "Thông điệp mới...",
+    "Send" : "Gửi",
+    "Today" : "Hôm nay",
+    "Yesterday" : "Hôm qua",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Error occurred while sending message" : "Đã xảy ra lỗi khi gửi tin nhắn",
+    "File to share" : "Tệp để chia sẻ",
+    "Error while sharing" : "Lỗi khi chia sẻ",
+    "Edit" : "Chỉnh sửa",
+    "No other people in this call" : "Không có người nào trong cuộc gọi này",
+    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
+    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
+    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
+    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
+    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
+    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
+    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
+    "Disable video" : "Tắt Video",
+    "Share screen" : "Chia sẽ màn hình",
+    "Show your screen" : "Hiện màn hình của bạn",
+    "Stop screensharing" : "Ngừng chia sẽ màn hình",
+    "Unmute audio (m)" : "Mở âm thanh (m)",
+    "Mute audio (m)" : "Tắt âm thành (m)",
+    "No audio" : "Không có âm thanh",
+    "Enable video (v)" : "Bật Video (v)",
+    "Disable video (v)" : "Tắt Video (v)",
+    "No Camera" : "Không có Camera",
+    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
+    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
+    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
+    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
+    "Enable screensharing" : "Bật chia sẽ màn hình",
+    "Add participant …" : "Thêm người tham gia …",
+    "Favorited" : "Được ưa thích",
+    "Close" : "Đóng",
+    "Show screen" : "Hiện màn hình",
+    "Enable video" : "Bật Video",
+    "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
+    "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
+    "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
+    "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
+    "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
+    "{participantName}'s screen" : "Màn hình của {participantName}",
+    "Guest's screen" : "Màn hình Khách",
+    "Your screen" : "Màn hình của bạn",
+    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Bạn đã được mời đến một <strong>phòng trò chuyện</strong> hoặc có một <strong>cuộc gọi</strong>",
     "_%n other guest_::_%n other guests_" : ["%nnhững khách khác "],
     ", " : ",",
-    "%s mentioned you in a private conversation" : "%sđã đề cập đến bạn trong cuộc trò chuyện riêng ",
-    "%s mentioned you in a group conversation: %s" : "%sđã đề cập đến bạn trong cuộc trò chuyện nhóm: %s ",
-    "{user} mentioned you in a group conversation: {call}" : "{user} đã đề cập đến bạn trong cuộc trò chuyện nhóm: {call}",
-    "%s mentioned you in a group conversation" : "%sđã đề cập đến bạn trong cuộc trò chuyện nhóm ",
-    "{user} mentioned you in a group conversation" : "{user} đã đề cập đến bạn trong cuộc trò chuyện nhóm",
-    "You were mentioned in a group conversation by a deleted user: %s" : "Bạn đã được đề cập trong cuộc trò chuyện nhóm của một người dùng đã bị xóa: %s",
-    "You were mentioned in a group conversation by a deleted user: {call}" : "Bạn đã được đề cập trong cuộc trò chuyện nhóm của một người dùng đã bị xóa: {call}",
-    "You were mentioned in a group conversation by a deleted user" : "Bạn đã được đề cập trong cuộc trò chuyện nhóm của một người dùng đã bị xóa",
-    "A guest mentioned you in a group conversation: %s" : "Một khách đã đề cập đến bạn trong cuộc trò chuyện nhóm: %s",
-    "A guest mentioned you in a group conversation: {call}" : "Một khách đã đề cập đến bạn trong cuộc trò chuyện nhóm: {call}",
-    "A guest mentioned you in a group conversation" : "Một khách đã đề cập đến bạn trong cuộc trò chuyện nhóm",
     "%s invited you to a private conversation" : "%sđã mời bạn tham gia cuộc trò chuyện riêng ",
     "%s invited you to a group conversation: %s" : "%sđã mời bạn tham gia cuộc trò chuyện nhóm: %s ",
     "%s invited you to a group conversation" : "%s đã mời bạn tham gia cuộc trò chuyện nhóm",
     "{user} invited you to a group conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm",
     "A group call has started" : "Một cuộc gọi nhóm đã được thực hiện",
-    "{email} requested the password to access a share" : "{email} đã yêu cầu mật khẩu để truy cập chia sẽ",
     "Video & audio-conferencing using WebRTC" : "Video & hội nghị âm thanh bằng WebRTC",
     "This call is password-protected" : "Cuộc gọi này được bảo vệ bằng mật khẩu",
     "Signaling server" : "Máy chủ đăng ký"
